@@ -1,6 +1,5 @@
-{package POEx::Role::TCPServer;
-our $VERSION = '0.100171';
-}
+package POEx::Role::TCPServer;
+$POEx::Role::TCPServer::VERSION = '1.100910';
 
 #ABSTRACT: A Moose Role that provides TCPServer behavior
 
@@ -145,116 +144,7 @@ POEx::Role::TCPServer - A Moose Role that provides TCPServer behavior
 
 =head1 VERSION
 
-version 0.100171
-
-=head1 REQUIRES
-
-=head2 METHODS
-
-=head3 handle_inbound_data($data, WheelID $id) is Event
-
-This required method will be passed the data received, and from which wheel 
-it came. 
-
-=cut
-
-=pod
-
-=head1 ATTRIBUTES
-
-=head2 socket_factory is: rw, isa: Object, predicate: has_socket_factory, clearer: clear_socket_factory
-
-The POE::Wheel::SocketFactory created in _start is stored here.
-
-=cut
-
-=pod
-
-=head2 wheels traits: ['Hash'], is: rw, isa: HashRef, clearer: clear_wheels
-
-When connections are accepted, a POE::Wheel::ReadWrite object is created and 
-stored in this attribute, keyed by WheelID. Wheels may be accessed via the
-following provided methods.
-
-=cut
-
-=pod
-
-=head2 filter is: rw, isa: Filter
-
-This stores the filter that is used when constructing wheels. It will be cloned
-for each connection accepted.
-
-=cut
-
-=pod
-
-=head2 listen_ip is: ro, isa: Str, required
-
-This will be used as the BindAddress to SocketFactory
-
-=cut
-
-=pod
-
-=head2 listen_port is: ro, isa: Int, required
-
-This will be used as the BindPort to SocketFactory
-
-=cut
-
-=pod
-
-=head1 METHODS
-
-=head2 after _start(@args) is Event
-
-The _start event is after-advised to do the start up of the SocketFactory.
-
-=cut
-
-=pod
-
-=head2 handle_on_connect(GlobRef $socket, Str $address, Int $port, WheelID $id) is Event
-
-handle_on_connect is the SuccessEvent of the SocketFactory instantiated in _start. 
-
-=cut
-
-=pod
-
-=head2 handle_listen_error(Str $action, Int $code, Str $message, WheelID $id) is Event
-
-handle_listen_error is the FailureEvent of the SocketFactory
-
-=cut
-
-=pod
-
-=head2 handle_socket_error(Str $action, Int $code, Str $message, WheelID $id) is Event
-
-handle_socket_error is the ErrorEvent of each POE::Wheel::ReadWrite instantiated.
-
-=cut
-
-=pod
-
-=head2 handle_on_flushed(WheelID $id) is Event
-
-handle_on_flushed is the FlushedEvent of each POE::Wheel::ReadWrite instantiated.
-
-=cut
-
-=pod
-
-=head2 shutdown() is Event
-
-shutdown unequivically terminates the TCPServer by clearing all wheels and 
-aliases, forcing POE to garbage collect the session.
-
-=cut
-
-=pod
+version 1.100910
 
 =head1 DESCRIPTION
 
@@ -269,17 +159,115 @@ is actually encouraged and can simplify code for the consumer.
 The only method that must be provided by the consuming class is 
 handle_inbound_data.
 
+=head1 PUBLIC_ATTRIBUTES
+
+=head2 listen_ip
+
+    is: ro, isa: Str, required
+
+This will be used as the BindAddress to SocketFactory
+
+=head2 listen_port
+
+    is: ro, isa: Int, required
+
+This will be used as the BindPort to SocketFactory
+
+=head1 PROTECTED_ATTRIBUTES
+
+=head2 socket_factory
+
+    is: rw, isa: Object, predicate: has_socket_factory, clearer: clear_socket_factory
+
+The POE::Wheel::SocketFactory created in _start is stored here.
+
+=head2 wheels
+
+    traits: Hash, is: rw, isa: HashRef, clearer: clear_wheels
+
+When connections are accepted, a POE::Wheel::ReadWrite object is created and 
+stored in this attribute, keyed by WheelID. Wheels may be accessed via the
+following provided methods.
+
+    {
+        'get_wheel'     => 'get',
+        'set_wheel'     => 'set',
+        'delete_wheel'  => 'delete',
+        'count_wheels'  => 'count',
+        'has_wheel'     => 'exists',
+    }
+
+=head2 filter
+
+    is: rw, isa: Filter
+
+This stores the filter that is used when constructing wheels. It will be cloned
+for each connection accepted. Defaults to a instance of POE::Filter::Line.
+
+=head1 PUBLIC_METHODS
+
+=head2 shutdown()
+
+    is Event
+
+shutdown unequivically terminates the TCPServer by clearing all wheels and 
+aliases, forcing POE to garbage collect the session.
+
+=head1 PROTECTED_METHODS
+
+=head2 handle_on_connect
+
+    (GlobRef $socket, Str $address, Int $port, WheelID $id) is Event
+
+handle_on_connect is the SuccessEvent of the SocketFactory instantiated in _start. 
+
+=head2 handle_listen_error
+
+    (Str $action, Int $code, Str $message, WheelID $id) is Event
+
+handle_listen_error is the FailureEvent of the SocketFactory
+
+=head2 handle_socket_error
+
+    (Str $action, Int $code, Str $message, WheelID $id) is Event
+
+handle_socket_error is the ErrorEvent of each POE::Wheel::ReadWrite instantiated.
+
+=head2 handle_on_flushed
+
+    (WheelID $id) is Event
+
+handle_on_flushed is the FlushedEvent of each POE::Wheel::ReadWrite instantiated.
+
+=head1 PRIVATE_METHODS
+
+=head2 after _start
+
+    (@args) is Event
+
+The _start event is after-advised to do the start up of the SocketFactory.
+
+=head1 REQUIRES
+
+=head2 METHODS
+
+=head3 handle_inbound_data
+
+    ($data, WheelID $id) is Event
+
+This required method will be passed the data received, and from which wheel 
+it came. 
+
 =head1 AUTHOR
 
-Nicholas Perez <nperez@cpan.org>
+  Nicholas Perez <nperez@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2010 by Nicholas Perez.
+This software is copyright (c) 2010 by Nicholas Perez.
 
-This is free software, licensed under:
-
-  The GNU General Public License, Version 3, June 2007
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
